/**********************************************************************************************************************					
Instituto Nacional de Estadstica (INE) www.ine.es					
***********************************************************************************************************************					
					
DESCRIPCIN:					
Este programa genera un fichero SAS con formatos, partiendo de un fichero sin ellos.					
					
Consta de las siguientes partes:					
	* 1. Definir la librera de trabajo --> Libname				
	* 2. Definicin de formatos --> PROC FORMAT				
	* 3. Vincular formatos a la base de datos --> PASO data				
					
 Entrada:                                                           					
     - Fichero SAS sin formatos: 	 ETEFIL_GM_2019.sas7bdat				
 Salida:                                                           					
     - Fichero SAS con formatos: 	 ETEFIL_GM_2019_conFormato.sas7bdat				
					
Donde:					
	* Operacin: Encuesta de Transicin Educativa-Formativa e Insercin Laboral (ETEFIL_CICLOS FORMATIVOS GRADO MEDIO)			
	* Periodo: 2019				
					
************************************************************************************************************************/					
					
/*1) Definir la librera de trabajo: introducir el directorio que desee como librera					
(se da como ejemplo 'C:\Mis resultados'), y copiar en ese directorio el fichero sas "ETEFIL_GM_2019.sas7bdat"*/					
					
libname ROutput 'C:\Mis resultados';					

options fmtsearch = (ROutput ROutput.cat1);

* 2) DEFINICIN DE FORMATOS;
PROC FORMAT LIBRARY=ROutput.cat1;
value $TSEXO

"1"="Hombre"
"2"="Mujer"
;
value $TANAC

"1969"="Nacidos en 1969 o antes"
"1996"="Nacidos en 1996 y 1997"
;
value $TNACIO

"1"="Espaola"
"2"="Espaola y otra"
"3"="Otra nacionalidad"
;
value $TNACIOP

"1"="Un pas de la UE"
"2"="Un pas fuera de la UE"
"9"="NS/NC"
" "="No aplicable"
;
value $TNACIP

"1"="Espaa"
"2"="Otro pas de la UE"
"3"="Otro pas fuera de la UE"
"9"="NS/NC"
;
value $TCENTRO

"1"="Pblico"
"2"="Privado"
"9"="NS/NC"
" "="No aplicable"
;
value $TCCAA

"01"="Andaluca"
"02"="Aragn"
"03"="Asturias, Principado de"
"04"="Balears, Illes"
"05"="Canarias"
"06"="Cantabria"
"07"="Castilla y Len"
"08"="Castilla - La Mancha"
"09"="Catalua"
"10"="Comunitat Valenciana"
"11"="Extremadura"
"12"="Galicia"
"13"="Madrid, Comunidad de"
"14"="Murcia, Regin de"
"15"="Navarra, Comunidad Foral de"
"16"="Pas Vasco"
"17"="Rioja, La"
"18"="Ceuta"
"19"="Melilla"
"99"="En Espaa: No consta Comunidad Autnoma"
"77"="En el extranjero"
"  "="No aplicable"
;
value $T1SINO

"1"="S"
"2"="No"
;
value $TPROXY

"1"="Entrevista directa con la persona seleccionada"
"2"="Entrevista proxy"
;
value $T1PAIS

"01"="Espaa"
"02"="Reino Unido"
"03"="Alemania"
"04"="Francia"
"05"="Otro pas de la Unin Europea"
"06"="Otro pas europeo (fuera de la UE)"
"07"="Un pas de Amrica del Norte"
"08"="Un pas de Amrica Central o Amrica del Sur"
"09"="Un pas de Asia"
"10"="Un pas de frica"
"11"="Un pas de Oceana"
"99"="NS/NC"
"  "="No aplicable"
;
value $TNFORMA

"1"="No sabe leer o escribir"
"2"="Educacin primaria incompleta (ha asistido menos de 5 aos a la escuela)"
"3"="Educacin primaria completa"
"4"="Primera etapa de Enseanza Secundaria, con o sin ttulo (ESO, EGB, Bachillerato Elemental)"
"5"="Estudios de Bachillerato (Bachillerato LOGSE, BUP, COU, Preu)"
"6"="Enseanzas profesionales de grado medio o equivalentes"
"7"="Enseanzas profesionales de grado superior o equivalentes"
"8"="Estudios universitarios (Diplomatura, Licenciatura, Doctorado) o equivalentes"
"9"="NS/NC"
;
value $T2SINO

"1"="S"
"2"="No"
"9"="NS/NC"
" "="No aplicable"
;
value $T2PAIS

"01"="REINO UNIDO"
"02"="ALEMANIA"
"03"="FRANCIA"
"04"="ITALIA"
"05"="PORTUGAL"
"06"="PASES NRDICOS (SUECIA, NORUEGA, FINLANDIA, DINAMARCA e ISLANDIA)"
"07"="OTRO PAS DE LA UNIN EUROPEA"
"08"="OTRO PAS EUROPEO"
"11"="UN PAS DE AMRICA DEL NORTE"
"12"="UN PAS DE AMRICA CENTRAL Y DEL SUR"
"21"="UN PAS DE ASIA"
"31"="UN PAS DE FRICA"
"41"="UN PAS DE OCEANA"
"99"="NS/NC"
"  "="No aplicable"
;
value $TMESF

"1"="De 1 a 3 meses"
"2"="De 4 a 6 meses"
"3"="Ms de 6 meses"
"9"="NS/NC"
" "="No aplicable"
;
value $TACCES

"1"="Graduado en ESO"
"2"="Mdulos voluntarios de un Programa de Cualificacin Profesional Inicial"
"3"="Mdulos obligatorios de un Programa de Cualificacin Profesional Inicial"
"4"="Prueba de acceso a los Ciclos Formativos de Grado Medio"
"5"="Otras"
"9"="NS/NC"
;
value $TESTU

"1"="Bachillerato"
"2"="Ciclos Formativos de Grado Medio (incluye Ciclos Formativos de Artes Plsticas y Diseo y Enseanzas Deportivas de Grado Medio)"
"3"="Enseanzas profesionales de Msica y Danza"
"4"="Ciclos Formativos de Grado Superior (incluye Ciclos Formativos de Artes Plsticas y Diseo y Enseanzas Deportivas de Grado Superior)"
"5"="Enseanzas universitarias"
"6"="Enseanzas Artsticas Superiores"
"7"="Curso de acceso a Ciclo Formativo de Grado Superior"
"9"="Abandon el sistema educativo (no se matricul o estuvo matriculado menos de dos meses)"
" "="No aplicable"
;
value $TMOD

"1"="Ciencias / Ciencia y tecnologa"
"2"="Ciencias sociales"
"3"="Humanidades"
"4"="Artes"
"9"="NS/NC"
" "="No aplicable"
;
value $TFAMIGM

"01"="Agraria"
"02"="Martimo-pesquera"
"03"="Industrias alimentarias"
"04"="Qumica"
"05"="Imagen personal"
"06"="Sanidad"
"07"="Seguridad y medio ambiente"
"08"="Fabricacin mecnica"
"09"="Instalacin y mantenimiento"
"10"="Electricidad y electrnica"
"12"="Transporte y mantenimiento de vehculos"
"13"="Industrias extractivas"
"14"="Edificacin y obra civil"
"15"="Vidrio y cermica"
"16"="Madera, mueble y corcho"
"17"="Textil, confeccin y piel"
"18"="Artes grficas"
"19"="Imagen y sonido"
"20"="Informtica y comunicaciones"
"21"="Administracin y gestin"
"22"="Comercio y marketing"
"23"="Servicios socioculturales y a la comunidad"
"24"="Hostelera y turismo"
"25"="Actividades fsicas y deportivas (incluidas enseanzas deportivas de grado medio)"
"88"="Otros ciclos formativos de Artes plasticas y diseo"
"89"="Doble grado medio"
"99"="NS/NC"
"  "="No aplicable"
;
value $TFAMIGS

"01"="Agraria"
"02"="Martimo-pesquera"
"03"="Industrias alimentarias"
"04"="Qumica"
"05"="Imagen personal"
"06"="Sanidad"
"07"="Seguridad y medio ambiente"
"08"="Fabricacin mecnica"
"09"="Instalacin y mantenimiento"
"10"="Electricidad y electrnica"
"11"="Energa y agua"
"12"="Transporte y mantenimiento de vehculos"
"14"="Edificacin y obra civil"
"15"="Vidrio y cermica"
"16"="Madera, mueble y corcho"
"17"="Textil, confeccin y piel"
"18"="Artes grficas"
"19"="Imagen y sonido"
"20"="Informtica y comunicaciones"
"21"="Administracin y gestin"
"22"="Comercio y marketing"
"23"="Servicios socioculturales y a la comunidad"
"24"="Hostelera y turismo"
"25"="Actividades fsicas y deportivas (incluidas enseanzas deportivas de grado superior)"
"26"="Artes y artesanas (incluidos otros ciclos formativos de Artes plsticas y diseo)"
"89"="Doble grado superior"
"99"="NS/NC"
"  "="No aplicable"
;
value $TAMBITO

"0112"="Formacin de docentes de enseanza infantil"
"0113"="Formacin de docentes de enseanza primaria"
"011"="Educacin (Otros estudios)"
"0211"="Tcnicas audiovisuales y medios de comunicacin"
"021"="Artes (Otros estudios)"
"022"="Humanidades"
"023"="Lenguas"
"0311"="Economa"
"0313"="Psicologa"
"031"="Ciencias sociales y del comportamiento (Otros estudios)"
"032"="Periodismo y documentacin"
"0413"="Direccin y administracin"
"041"="Negocios y administracin (Otros estudios)"
"042"="Derecho"
"051"="Ciencias de la vida"
"052"="Medio ambiente"
"053"="Ciencias qumicas, fsicas y geolgicas"
"054"="Matemticas y estadstica"
"061"="Tecnologas de la informacin y las comunicaciones"
"071"="Ingeniera y profesiones afines"
"072"="Industria manufacturera y produccin"
"073"="Arquitectura y construccin"
"081"="Agricultura y ganadera"
"082"="Silvicultura"
"083"="Pesca"
"084"="Veterinaria"
"0912"="Medicina"
"0913"="Enfermera"
"091"="Salud (Otros estudios)"
"092"="Servicios sociales"
"1014"="Actividades fsicas y deportivas"
"1015"="Viajes, turismo y ocio"
"109"="Servicios (Otros estudios)"
"8881"="Doble grado ADE + Derecho"
"8882"="Doble grado ADE + Turismo"
"8883"="Doble grado Maestro en educacin infantil + Maestro en educacin primaria"
"8888"="Dobles grados (Otros estudios)"
"9999"="Grado desconocido"
"M1"="Mster en ciencias"
"M2"="Mster en ciencias de la salud"
"M3"="Mster en ciencias sociales y jurdicas"
"M4"="Mster en arte y humanidades"
"M5"="Mster en ingeniera y arquitectura"
"M9"="Mster desconocido"
"D1"="Doctorado en ciencias"
"D2"="Doctorado en ciencias de la salud"
"D3"="Doctorado en ciencias sociales y jurdicas"
"D4"="Doctorado en arte y humanidades"
"D5"="Doctorado en ingeniera y arquitectura"
"D9"="Doctorado desconocido"
"    "="No aplicable"
;
value $TRAZON

"1"="Porque vea difcil encontrar trabajo"
"2"="Porque le gustaban"
"3"="Porque consideraba que con esos estudios incrementara sus posibilidades de encontrar trabajo"
"4"="Porque anteriormente no haba podido realizarlos y ya era posible"
"5"="Por influencia de familiares"
"7"="Por influencia de amigos"
"9"="NS/NC"
" "="No aplicable"
;

value $T1MOTIV

"01"="Consigui el nivel de formacin / ttulo deseado"
"02"="Por cambios en la situacin personal / familiar (motivos personales, econmicos,)"
"03"="Encontr un empleo"
"04"="Prepar / aprob unas oposiciones"
"05"="Para realizar otros estudios"
"06"="No quera seguir estudiando porque estaba cansado de estudiar"
"07"="No quera seguir estudiando porque no le gustaban los estudios que estaba realizando"
"08"="No quera seguir estudiando porque los estudios que realizaba eran difciles / obtuvo malos resultados"
"09"="No quera seguir estudiando porque quera buscar trabajo"
"99"="NS/NC"
"  "="No aplicable"
;
value $T2MOTIV

"1"="Para encontrar una mejor salida al mercado laboral"
"2"="Por influencia de familiares"
"3"="Por influencia de amigos"
"4"="Porque prefera estudiar a estar en otras situaciones"
"5"="Porque antes no haba podido realizarlos y luego s fue posible"
"9"="NS/NC"
" "="No aplicable"
;
value $T1CURSO

"1"="Curso 2015/16"
"2"="Curso 2016/17"
"3"="Curso 2017/18"
"4"="Curso 2018/19"
"5"="Curso 2019/20"
"9"="NS/NC"
" "="No aplicable"
;
value $T3MOTIV

"1"="Porque eran difciles / obtuvo malos resultados"
"2"="Por cambios en la situacin personal / familiar (motivos personales, econmicos, )"
"3"="Porque quera realizar otros estudios"
"9"="NS/NC"
" "="No aplicable"
;
value $T2CURSO

"1"="Curso 2016/17"
"2"="Curso 2017/18"
"3"="Curso 2018/19"
"4"="Curso 2019/20"
"9"="NS/NC"
" "="No aplicable"
;
value $T3CURSO

"1"="Curso 2017/18"
"2"="Curso 2018/19"
"3"="Curso 2019/20"
"9"="NS/NC"
" "="No aplicable"
;
value $T4CURSO

"1"="Curso 2018/19"
"2"="Curso 2019/20"
"9"="NS/NC"
" "="No aplicable"
;
value $Tidioma

"01"="Espaol"
"02"="Cataln"
"03"="Euskera"
"04"="Gallego"
"05"="Valenciano"
"06"="Ingls"
"07"="Francs"
"08"="Alemn"
"09"="Italiano"
"10"="Portugus"
"11"="Rumano"
"12"="rabe"
"13"="Chino"
"14"="Ruso"
"15"="Otros idiomas"
"99"="NS/NC"
"  "="No aplicable"
;
value $TNUMIDI

"0"="Ninguno"
"1"="1"
"2"="2"
"3"="3"
"4"="4"
"5"="5 o ms"
"9"="NS/NC"
;
value $TNivIdi

"1"="Nivel alto (Entiende una gran variedad de textos complicados y usa el idioma con flexibilidad)"
"2"="Nivel medio (Entiende lo esencial en el lenguaje comn y redacta textos sencillos)"
"3"="Nivel bajo (Entiende y usa las expresiones ms comunes )"
"9"="NS/NC"
" "="No aplicable"
;
value $TTIC

"1"="No sabe usar el ordenador ni otros dispositivos informticos"
"2"="Usuario de nivel bsico (navegar por internet, enviar correos electrnicos, copiar o mover archivos o carpetas, escribir un texto usando un procesador de textos, usar frmulas simples en hojas de clculo)"
"3"="Usuario de nivel intermedio (dar formato a textos, usar frmulas ms avanzadas y crear grficos en hojas de clculo, instalar dispositivos y/o programas, usar bases de datos)"
"4"="Usuario de nivel avanzado (escribir macros, programar, resolver problemas de software y hardware cuando el ordenador no funciona adecuadamente)"
"9"="NS/NC"
;
value $TPAIMOV

"01"="Reino Unido"
"02"="Alemania"
"03"="Francia"
"07"="Otro pas de la Unin Europea"
"08"="Otro pas europeo"
"11"="Un pas de Amrica del Norte"
"12"="Un pas de Amrica Central o Amrica del Sur"
"21"="Un pas de Asia"
"31"="Un pas de frica"
"41"="Un pas de Oceana"
"88"="No ha residido en ningn otro pas"
"99"="NS/NC"
"  "="No aplicable"
;
value $TVIVIRF

"1"="S, ya lo tiene todo preparado y se va a ir en los prximos meses"
"2"="S, se lo ha planteado y se ira a vivir fuera de Espaa"
"3"="S, se lo ha planteado pero ha decidido quedarse a vivir en Espaa"
"4"="No, no se lo ha planteado"
"9"="NS/NC"
" "="No aplicable"
;
value $T1TRBPN

"1"="Trabajando"
"2"="En desempleo"
"3"="Inactivo"
;
value $T2TRBPN

"1"="Estudiante (estudiante o preparando oposiciones)"
"2"="Jubilado"
"3"="Incapacitado para trabajar"
"4"="Dedicado a las labores del hogar"
"5"="Otra situacin"
"9"="NS/NC"
" "="No aplicable"
;
value $T1MOBUT

"1"="Antes de finalizar el curso 2013/14"
"2"="Despus de finalizar el curso 2013/14"
"9"="NS/NC"
" "="No aplicable"
;
value $T1TIEMP

"1"="Menos de tres meses"
"2"="De 3 a 6 meses"
"3"="De 6 meses a 1 ao"
"4"="De 1 ao a ao y medio"
"5"="De 1 ao y medio a 2 aos"
"6"="2  ms aos"
"9"="NS/NC"
" "="No aplicable"
;
value $TIMPORT

"1"="Nada importante"
"2"="Poco importante"
"3"="Bastante importante"
"4"="Muy importante"
"9"="NS/NC"
" "="No aplicable"
;
value $TStProf

"1"="Trabajador en prcticas, formacin o becario"
"2"="Asalariado con trabajo permanente o contrato de trabajo de duracin indefinida"
"3"="Asalariado con trabajo temporal o contrato de trabajo de duracin determinada"
"4"="Empresario con asalariados"
"5"="Trabajador independiente o empresario sin asalariados"
"6"="Ayuda en la empresa o negocio familiar"
" "="No aplicable"
;
value $TJornad

"1"="A tiempo parcial"
"2"="A tiempo completo"
"9"="NS/NC"
" "="No aplicable"
;
value $TTamano

"0"="Trabajadores independientes o autnomos sin asalariados"
"1"="De 1 a 10 personas"
"2"="Entre 11 y 49 personas"
"3"="Entre 50 y 249 personas"
"4"="250 o ms personas"
"9"="NS/NC"
" "="No aplicable"
;
value $TAnio

"9999"="NS/NC"
"    "="No aplicable"
;
value $TSUELDO

"1"="Menos de 700 euros"
"2"="De 700 a 999 euros"
"3"="De 1.000 a 1.499 euros"
"4"="De 1.500 a 1.999 euros"
"5"="De 2.000 a 2.499 euros"
"6"="De 2.500 a 2.999 euros"
"7"="De 3.000 euros en adelante"
"9"="NS/NC"
" "="No aplicable"
;
value $TNivEst

"1"="Doctorado"
"2"="Mster"
"3"="Ttulo universitario (excepto doctorado o mster)"
"4"="Formacin profesional de grado superior"
"5"="Formacin profesional de grado medio/ bachillerato"
"6"="Formacin profesional bsica"
"7"="ESO, EGB, etc."
"9"="NS/NC"
" "="No aplicable"
;
value $TFORM

"1"="S"
"2"="No, precisara de mayor formacin terica"
"3"="No, precisara de mayor formacin prctica"
"4"="No, precisara de mayor formacin tanto terica como prctica"
"9"="NS/NC"
" "="No aplicable"
;
value $TFacTrb

"1"="Nada"
"2"="Poco"
"3"="Algo"
"4"="Bastante"
"5"="Mucho"
"9"="NS/NC"
" "="No aplicable"
;
value $T3SiNo

"1"="S"
"2"="No, pero est esperando respuesta a solicitudes anteriores de empleo o los resultados de una oposicin"
"3"="No"
"9"="NS/NC"
" "="No aplicable"
;
value $T1SATIS

"1"="Nada satisfecho"
"2"="Poco satisfecho"
"3"="Satisfecho"
"4"="Bastante satisfecho"
"5"="Muy satisfecho"
"9"="NS/NC"
" "="No aplicable"
;
value $T2TIEMP

"0"="Continu al menos 6 meses ms en el trabajo que tena mientras estudiaba"
"1"="Menos de tres meses"
"2"="De 3 a 6 meses"
"3"="De 6 meses a 1 ao"
"4"="De 1 ao a ao y medio"
"5"="De 1 ao y medio a 2 aos"
"6"="2  ms aos"
"9"="NS/NC"
" "="No aplicable"
;
value $T2MOBUT

"0"="Continu al menos 6 meses ms en el trabajo que tena mientras estudiaba"
"1"="Antes de finalizar el curso 2013/14"
"2"="Despus de finalizar el curso 2013/14"
"9"="NS/NC"
" "="No aplicable"
;
value $T3TIEMP

"1"="Menos de 6 meses"
"2"="De 6 meses a 1 ao"
"3"="De 1 ao a ao y medio"
"4"="De 1 ao y medio a 2 aos"
"5"="2 o ms aos"
"9"="NS/NC"
" "="No aplicable"
;
value $TNmEmpl

"11"="11 o ms"
"99"="NS/NC"
"  "="No aplicable"
;
value $T2SATIS

"1"="Muy satisfecho"
"2"="Bastante satisfecho"
"3"="Poco satisfecho"
"4"="Nada satisfecho"
"9"="NS/NC"
" "="No aplicable"
;
value $TESTCIV

"1"="Soltero"
"2"="Casado"
"3"="Viudo"
"4"="Separado"
"5"="Divorciado"
"9"="NS/NC"
;
value $TNPER

"6"="6 o ms"
"9"="NS/NC"
" "="No aplicable"
;
value $TTIPO

"1"="Hogar unipersonal"
"2"="Padre o madre solo/a que convive con algn hijo menor de 25 aos"
"3"="Padre o madre solo/a que convive con todos sus hijos de 25 aos o ms"
"4"="Pareja sin hijos que convivan en el hogar"
"5"="Pareja con algn hijo menor de 25 aos y que conviven en el hogar"
"6"="Pareja con algn hijo menor pero todos de 25 aos  ms y que conviven en el hogar"
"7"="Pareja, o un padre/madre, que conviven con hijos menores de 25 aos, y otras personas"
"8"="Otro tipo de hogar"
"9"="NS/NC"
;
value $TCOTIZ

"1"="Por cuenta propia"
"2"="Por cuenta ajena"
"3"="Por cuenta propia y ajena"
" "="No aplicable"
;
value $TQuintl

"1"="Primer quintil"
"2"="Segundo quintil"
"3"="Tercer quintil"
"4"="Cuarto quintil"
"5"="Quinto quintil"
"9"="NS/NC"
" "="No aplicable"
;
value $TNuCurs

"0"="No ha realizado ningn curso de formacin del SEPE"
"1"="Un curso de formacin del SEPE"
"2"="Dos cursos de formacin del SEPE"
"3"="Tres cursos de formacin del SEPE"
"4"="Cuatro cursos de formacin del SEPE"
"5"="Cinco cursos de formacin del SEPE"
"6"="Seis cursos de formacin del SEPE"
;
value $TDsCurs

"01"="Administracin y gestin"
"02"="Actividades fsicas y deportivas"
"03"="Agraria"
"04"="Artes grficas"
"05"="Artes y artesanas"
"06"="Comercio y marketing"
"07"="Electricidad y electrnica"
"08"="Energa y agua"
"09"="Edificacin y obra civil"
"10"="Formacin complementaria"
"11"="Fabricacin mecnica"
"12"="Hostelera y turismo"
"13"="Industrias extractivas"
"14"="Informtica y comunicaciones"
"15"="Instalacin y mantenimiento"
"16"="Imagen personal"
"17"="Imagen y sonido"
"18"="Industrias alimentarias"
"19"="Madera, mueble y corcho"
"20"="Martimo pesquera"
"21"="Qumica"
"22"="Sanidad"
"23"="Seguridad y medioambiente"
"24"="Servicios socioculturales y a la comunidad"
"25"="Textil, confeccin y piel"
"26"="Transporte y mantenimiento de vehculos"
"27"="Vidrio y cermica"
"99"="NS/NC"
"  "="No aplicable"
;
value $TDrCurs

"1"="200 horas o menos"
"2"="De 201 a 300 horas"
"3"="De 301 a 500 horas"
"4"="Ms de 500 horas"
" "="No aplicable"
;
value $TReCurs

"1"="Abandona por colocacin"
"2"="Abandona por otras causas"
"3"="Termina con evaluacin positiva"
"4"="Termina con evaluacin negativa"
" "="No aplicable"
;
value $TAnCurs

"    "="No aplicable"
;
value $TCODGRU

"12110103"="Tcnico en jardinera y floristera"
"12110104"="Tcnico en aprovechamiento y conservacin del medio natural"
"12110109"="Tcnico en produccin agroecolgica y Tcnico en produccin agropecuaria"
"12110200"="02 - MARTIMO-PESQUERA"
"12110300"="03 - INDUSTRIAS ALIMENTARIAS"
"12110400"="04 - QUMICA"
"12110501"="Tcnico en esttica y belleza"
"12110502"="Tcnico en peluquera y cosmtica capilar y Tcnico en Caracterizacin"
"12110601"="Tcnico en emergencias sanitarias"
"12110602"="Tcnico en farmacia y parafarmacia"
"12110699"="Cuidados auxiliares de enfermera"
"12110801"="Tcnico en mecanizado"
"12110809"="Tcnico en soldadura y calderera, Tcnico en conformado por moldeo de metales y polmeros y Tcnico en Joyera"
"12110903"="Tcnico en mantenimiento electromecnico"
"12110909"="Tcnico en instalaciones de produccin de calor, Tcnico en instalaciones frigorficas y de climatizacin e Instalacin y mantenimiento (Sin distribuir)"
"12111001"="Tcnico en instalaciones elctricas y automticas"
"12111002"="Tcnico en instalaciones de telecomunicaciones"
"12111099"="Equipos electrnicos de consumo"
"12111201"="Tcnico en carrocera"
"12111209"="Tcnico en electromecnica de vehculos automviles, Tcnico en electromecnica de maquinaria y Mantenimiento de material rodante ferroviario"
"12111600"="16 - MADERA, MUEBLE Y CORCHO"
"12111800"="18 - ARTES GRFICAS"
"12111900"="19 - IMAGEN Y SONIDO"
"12112001"="20 - INFORMTICA Y COMUNICACIONES"
"12112100"="21 - ADMINISTRACIN Y GESTIN"
"12112201"="22 - COMERCIO Y MARKETING"
"12112301"="23 - SERVICIOS SOCIOCULTURALES Y A LA COMUNIDAD"
"12112401"="Tcnico en cocina y gastronoma"
"12112402"="Tcnico en servicios de restauracin"
"12112501"="25 - ACTIVIDADES FSICAS Y DEPORTIVAS"
"12119900"="14 - EDIFICACIN Y OBRA CIVIL; 15 - VIDRIO Y CERMICA; 17 - TEXTIL, CONFECCIN Y PIEL"
;
value $TOcupac

"11"="Miembros del poder ejecutivo y de los cuerpos legislativos; directivos de la Administracin Pblica y organizaciones de inters social; directores ejecutivos"
"12"="Directores de departamentos administrativos y comerciales (directores financieros, directores de recursos humanos, directores comerciales, directores de publicidad, directores de desarrollo,)"
"13"="Directores de produccin y operaciones: Directores de produccin de explotaciones agropecuarias, forestales y pesqueras, y de industrias manufactureras, de minera, construccin,; Directores de servicios de TIC y de empresas de servicios profesionales"
"14"="Directores y gerentes de empresas de alojamiento, restauracin y comercio"
"15"="Directores y gerentes de otras empresas de servicios no clasificados bajo otros epgrafes: Directores y gerentes de empresas de actividades recreativas, culturales y deportivas; Directores y gerentes de empresas de gestin de residuos y de otros servicios no clasificados bajo otros epgrafes"
"21"="Profesionales de la salud: Mdicos; Profesionales de enfermera y partera; Veterinarios; Farmacuticos; Otros profesionales de la salud (odontlogos, fisioterapeutas, dietistas, logopedas,)"
"22"="Profesionales de la enseanza infantil, primaria, secundaria y postsecundaria: Profesores de universidades y otra enseanza superior; Profesores de formacin profesional; Profesores de enseanza secundaria; Profesores de enseanza primaria; Maestros y educadores de enseanza infantil"
"23"="Otros profesionales de la enseanza: Profesores y tcnicos de educacin especial; Otros profesores y profesionales de la enseanza (profesores de enseanza no reglada de idiomas, msica y danza, artes, profesionales de la educacin ambiental, )"
"24"="Profesionales de la ciencias fsicas, qumicas, matemticas y de las ingenieras: Fsicos, qumicos, matemticos y afines; Profesionales en ciencias naturales (bilogos, ingenieros agrnomos, de montes, tcnicos agrcolas, ); Ingenieros; Arquitectos, urbanistas e ingenieros gegrafos; Ingenieros tcnicos; Arquitectos tcnicos, topgrafos y diseadores"
"25"="Profesionales en derecho: Jueces, magistrados, abogados y fiscales; Otros profesionales del derecho (notarios y registradores, procuradores, )"
"26"="Especialistas en organizacin de la Administracin Pblica y de las empresas y en la comercializacin: Especialistas en finanzas; Especialistas en organizacin y administracin; Tcnicos de empresas y actividades tursticas; Profesionales de ventas tcnicas y mdicas (excepto las TIC); Otros profesionales de las ventas, la comercializacin, la publicidad y las relaciones pblicas"
"27"="Profesionales de las tecnologas de la informacin: Analistas y diseadores de software y multimedia; Especialistas en bases de datos y en redes informticas"
"28"="Profesionales en ciencias sociales: Economistas; Socilogos, historiadores, psiclogos y otros profesionales en ciencias sociales (gegrafos, antroplogos, arquelogos, filsofos, profesionales en ciencias polticas); Sacerdotes de las distintas religiones"
"29"="Profesionales de la cultura y el espectculo: Archivistas, bibliotecarios, conservadores y afines; Escritores, periodistas y lingistas (fillogos, intrpretes y traductores); Artistas creativos e interpretativos (compositores, msicos, cantantes, coregrafos, bailarines, directores de cine, de teatro y afines, actores, locutores de radio, televisin, profesionales de espectculos taurinos, ...)"
"31"="Tcnicos de las ciencias y de las ingenieras: Delineantes y dibujantes tcnicos; Tcnicos de las ciencias fsicas, qumicas, medioambientales y de las ingenieras; Tcnicos en control de procesos (tcnicos en instalaciones de produccin de energa, en instalaciones de tratamiento de residuos, aguas, tcnicos de refineras de petrleo y gas natural,...); Tcnicos de las ciencias naturales y profesionales auxiliares afines; Profesionales en navegacin martima y aeronutica; Tcnicos de control de calidad de las ciencias fsicas, qumicas y de las ingenieras"
"32"="Supervisores en ingeniera de minas, de industrias manufactureras y de la construccin"
"33"="Tcnicos sanitarios y profesionales de las terapias alternativas: Tcnicos sanitarios de laboratorio, pruebas diagnsticas y prtesis; Otros tcnicos sanitarios (tcnicos superiores en higiene bucodentasl en documentacin sanitaria, en diettica, ayudantes de veterinaria, ...); Profesionales de las terapias alternativas (profesionales de la acupuntura, la naturopata, la homeopata, ...)"
"34"="Profesionales de apoyo en finanzas y matemticas (Profesionales de apoyo e intermediarios de cambio, bolsa y finanzas; Comerciales de prstamos y crditos; Tenedores de libros; Profesionales de apoyo en servicios estadsticos, matemticos y afines; Tasadores)"
"35"="Representantes, agentes comerciales y afines (Mediadores y agentes de seguros; Consignatarios; Representantes de aduanas; Organizadores de conferencias y eventos; Agentes o intermediarios en la contratacin de la mano de obra; Portavoces y agentes de relaciones pblicas)"
"36"="Profesionales de apoyo a la gestin administrativa; tcnicos de las fuerzas y cuerpos de seguridad: Asistentes administrativos y especializados (Supervisores de secretara, secretarios de centros mdicos o clnicas,...); Agentes de aduanas, tributos y afines que trabajan en tareas propias de la Administracin Pblica; Tcnicos de las fuerzas y cuerpos de seguridad (tcnicos de la polica nacional, autonmica y local, suboficiales de la guardia civil)"
"37"="Profesionales de apoyo de servicios jurdicos, sociales, culturales, deportivos y afines: Profesionales de apoyo de servicios jurdicos y sociales (detectives privados, animadores comunitarios, auxiliares laicos de las religiones,); Deportistas, entrenadores, instructores de actividades deportivas; monitores de actividades recreativas; Tcnicos y profesionales de apoyo de actividades culturales, artsticas y culinarias (fotgrafos, diseadores y decoradores de interior, chefs,...)"
"38"="Tcnicos de las tecnologas de la informacin y las comunicaciones (TIC): Tcnicos en operaciones de tecnologas de la informacin y asistencia al usuario; Programadores informticos; Tcnicos en grabacin audiovisual, radiodifusin y telecomunicaciones"
"41"="Empleados en servicios contables, financieros, y de servicios de apoyo a la produccin y al transporte (Empleados de contabilidad, de control de personal y nminas, de oficina de servicios estadsticos, financieros y bancarios, de control de abastecimientos e inventario, de logstica y transporte de pasajeros y mercancas, ...)"
"42"="Empleados de bibliotecas, servicios de correos y afines"
"43"="Otros empleados administrativos sin tareas de atencin al pblico (grabadores de datos, empleados administrativos sin tareas de atencin al pblico no clasificados bajo otros epgrafes)"
"44"="Empleados de agencias de viajes, recepcionistas y telefonistas; empleados de ventanilla y afines (excepto taquilleros): Empleados de informacin y recepcionistas (excepto de hoteles); Empleados de agencias de viajes, recepcionistas de hoteles y telefonistas; Agentes de encuestas; Empleados de ventanilla y afines (excepto taquilleros) (cajeros de bancos, empleados de sala de juegos, empleados de mostrador de correos,...)"
"45"="Empleados administrativos con tareas de atencin al pblico no clasificados bajo otros epgrafes"
"50"="Camareros y cocineros propietarios"
"51"="Trabajadores asalariados de los servicios de restauracin: Cocineros asalariados; Camareros asalariados"
"52"="Dependientes en tiendas y almacenes: Jefes de seccin de tiendas y almacenes; Vendedores en tiendas y almacenes"
"53"="Comerciantes propietarios de tiendas"
"54"="Vendedores (excepto en tiendas y almacenes): Vendedores en quioscos o en mercadillos; Operadores de telemarketing; Expendedores de gasolineras; Otros vendedores (vendedores a domicilio, promotores de venta, modelos de moda, arte y publicidad,)"
"55"="Cajeros y taquilleros (excepto bancos)"
"56"="Trabajadores de los cuidados a las personas en servicios de salud: Auxiliares de enfermera; Tcnicos auxiliares de farmacia y emergencias sanitarias y otros trabajadores de los cuidados a las personas en servicios de salud"
"57"="Otros trabajadores de los cuidados a las personas: Trabajadores de los cuidados personales a domicilio; Cuidadores de nios (en guarderas y centros educativos, en domicilios)"
"58"="Trabajadores de los servicios personales: Peluqueros y especialistas en tratamientos de esttica, bienestar y afines; Trabajadores que atienden a viajeros, guas tursticos y afines (auxiliares de vuelo y camareros de avin, barco y tren, revisores y cobradores de transporte terrestre, acompaantes tursticos, azafatos de tierra,...); Supervisores de mantenimiento y limpieza de edificios, conserjes y mayordomos domsticos; Trabajadores propietarios de pequeos alojamientos; Otros trabajadores de servicios personales (empleados de pompas fnebres y embalsamadores, cuidadores de animales y adiestradores, instructores de autoescuela, astrlogos, adivinadores,...)"
"59"="Trabajadores de los servicios de proteccin y seguridad: Guardias civiles; Policas (nacionales, autonmicos y locales); Bomberos; Personal de seguridad privado; Otros trabajadores de los servicios de proteccin y seguridad (vigilantes de prisiones, baistas-socorristas, agentes forestales y medioambientales,...)"
"61"="Trabajadores cualificados en actividades agrcolas"
"62"="Trabajadores cualificados en actividades ganaderas, (incluidas avcolas, apcolas y similares)"
"63"="Trabajadores cualificados en actividades agropecuarias mixtas"
"64"="Trabajadores cualificados en actividades forestales, pesqueras y cinegticas"
"71"="Trabajadores en obras estructurales de construccin y afines: Trabajadores en hormign, encofradores, ferrallistas y afines; Albailes, canteros, tronzadores, labrantes y grabadores de piedras; Carpinteros (excepto ebanistas y montadores de estructuras metlicas); Otros trabajadores de las obras estructurales de construccin (mantenedores de edificios, instaladores de fachadas tcnicas, instaladores de sistemas de impermeabilizacin en edificios,...)"
"72"="Trabajadores de acabado de construcciones e instalaciones (excepto electricistas), pintores y afines: Escayolistas y aplicadores de revestimientos de pasta y mortero; Fontaneros e instaladores de tuberas; Pintores, empapeladores y afines; Soladores, colocadores de parquet y afines; Mecnicos-instaladores de refrigeracin y climatizacin; Otros trabajadores de acabado en la construccin, instalaciones (excepto electricistas) y afines (montadores de cubiertas, cristaleros, montadores-instaladores de placas de energa solar, personal de limpieza de fachadas de edificios y chimeneas,...)"
"73"="Soldadores, chapistas, montadores de estructuras metlicas, herreros, elaboradores de herramientas y afines: Moldeadores, soldadores, chapistas, montadores de estructuras metlicas y trabajadores afines; Herreros y trabajadores de la fabricacin de herramientas y afines"
"74"="Mecnicos y ajustadores de maquinaria (vehculos de motor, motores de avin, maquinaria agrcola e industrial, maquinaria naval y ferroviaria, reparadores de bicicletas,)"
"75"="Trabajadores especializados en electricidad y electrotecnologa: Electricistas de la construccin y afines; Otros instaladores y reparadores de equipos elctricos; Instaladores y reparadores de equipos electrnicos y de telecomunicaciones"
"76"="Mecnicos de precisin en metales, ceramistas, vidrieros, artesanos y trabajadores de artes grficas: Mecnicos de precisin en metales, ceramistas, vidrieros y artesanos (relojeros, afinadores de instrumentos musicales, joyeros, alfareros, sopladores de vidrio, rotulistas, artesanos en madera, cesteros, artesanos en tejidos, cueros y materiales similares,...); Oficiales y operarios de las artes grficas (trabajadores de procesos de preimpresin, impresin, encuadernacin)"
"77"="Trabajadores de la industria de la alimentacin, bebidas y tabaco (matarifes, trabajadores de las industrias del pescado, panaderos, pasteleros, trabajadores del tratamiento de la leche, trabajadores de la elaboracin de bebidas, catadores, )"
"78"="Trabajadores de la madera, textil, confeccin, piel, cuero, calzado y otros operarios en oficios: Trabajadores que tratan la madera y afines; Ebanistas y trabajadores afines; Trabajadores del textil, confeccin, piel, cuero y calzado; Pegadores, buceadores, probadores de productos y otros operarios y artesanos diversos"
"81"="Operadores de instalaciones y maquinaria fijas: Operadores en instalaciones de la extraccin y explotacin de minerales; Operadores en instalaciones para el tratamiento de metales; Operadores de instalaciones y mquinas de productos qumicos, farmacuticos y materiales fotosensibles; Operadores en instalaciones para el tratamiento y transformacin de la madera, la fabricacin de papel, productos de papel y caucho o materias plsticas; Operadores de mquinas para fabricar productos textiles y artculos de piel y de cuero; Operadores de mquinas para elaborar productos alimenticios, bebidas y tabaco; Operadores de mquinas de lavandera y tintorera; Otros operadores de instalaciones y maquinaria fijas"
"82"="Montadores y ensambladores en fbricas (de maquinaria mecnica, de equipos elctricos y electrncios,)"
"83"="Maquinistas de locomotoras, operadores de maquinaria agrcola y de equipos pesados mviles, y marineros: Maquinistas de locomotoras y afines; Operadores de maquinaria agrcola y forestal mvil; Operadores de otras mquinas mviles (maquinaria de movimientos de tierras, gras, montacargas, carretillas elevadoras,...); Marineros de puente, marineros de mquinas y afines"
"84"="Conductores de vehculos para el transporte urbano o por carretera: Conductores de automviles, taxis y furgonetas; Conductores de autobuses y tranvas; Conductores de camiones; Conductores de motocicletas y ciclomotores"
"91"="Empleados domsticos"
"92"="Otro personal de limpieza: Personal de limpieza de oficinas, hoteles y otros establecimientos similares; Limpiadores de vehculos, ventanas y personal de limpieza a mano"
"93"="Ayudantes de preparacin de alimentos: Ayudantes de cocina; Preparadores de comidas rpidas"
"94"="Recogedores de residuos urbanos, vendedores callejeros y otras ocupaciones elementales en servicios: Vendedores callejeros; Repartidores de publicidad, limpiabotas y otros trabajadores de oficios callejeros; Ordenanzas, mozos de equipaje, repartidores a pie y afines; Recogedores de residuos, clasificadores de desechos, barrenderos y afines; Otras ocupaciones elementales"
"95"="Peones agrarios, forestales y de la pesca: Peones agrcolas; Peones ganaderos; Peones agropecuarios; Peones de la pesca, la acuicultura, forestales y de la caza"
"96"="Peones de la construccin y de la minera"
"97"="Peones de las industrias manufactureras"
"98"="Peones del transporte, descargadores y reponedores"
"00"="Ocupaciones militares: Oficiales y suboficiales de las fuerzas armadas; Tropa y marinera de las fuerzas armadas"
"99"="NS/NC"
"  "="No aplicable"
;
value $TCNAE

"AA"="Agricultura, ganadera, silvicultura y pesca"
"BB"="Industrias extractivas"
"CC"="Industria manufacturera"
"DD"="Suministro de energa elctrica, gas, vapor y aire acondicionado"
"EE"="Suministro de agua, actividades de saneamiento, gestin de residuos y descontaminacin"
"FF"="Construccin e ingeniera civil"
"GG"="Comercio al por mayor y al por menor; reparacin de vehculos de motor y motocicletas"
"HH"="Transporte, almacenamiento, actividades postales y de correos"
"II"="Hostelera"
"JJ"="Informacin y comunicaciones (actividades de edicin, cinematogrficas, de vdeo, de sonido, programas de televisin, telecomunicaciones, programacin informtica y servicios de informacin)"
"KK"="Actividades financieras y de seguros"
"LL"="Actividades inmobiliarias"
"M1"="Actividades profesionales, cientficas y tcnicas"
"M2"="Actividades de fotografa"
"M3"="Actividades veterinarias"
"N1"="Actividades de alquiler"
"N2"="Actividades relacionadas con el empleo"
"N3"="Actividades de agencias de viajes, operadores tursticos, servicios de reservas y actividades relacionadas con los mismos"
"N4"="Actividades de seguridad e investigacin"
"N5"="Servicios a edificios y actividades de jardinera"
"N6"="Actividades administrativas de oficina y otras actividades auxiliares a las empresas"
"OO"="Administracin Pblica y defensa; Seguridad Social obligatoria"
"PP"="Educacin"
"QQ"="Actividades sanitarias y de servicios sociales"
"RR"="Actividades artsticas, culturales, recreativas, deportivas y de entrenimiento"
"S1"="Actividades asociativas y sindicales"
"S2"="Reparacin de ordenadores"
"S3"="Efectos personales y artculos de uso domstico y otros servicios personales (lavado y limpieza de prendas, peluquera y otros tratamientos de belleza, pompas fnebres y actividades relacionadas)"
"S4"="Actividades de mantenimiento fsico"
"TT"="Particulares como empleadores de personal domstico; particulares como productores de bienes y servicios para uso propio"
"UU"="Actividades de organizaciones y organismos extraterritoriales"
"99"="NS/NC"
"  "="No aplicable"
;



* 3) VINCULAR FORMATOS A LA BASE DE DATOS;
data ROutput.ETEFIL_GM_2019_ConFormato;
	set ROutput.ETEFIL_GM_2019;

FORMAT SEXO $TSEXO.;
FORMAT ANIO_NAC $TANAC.;
FORMAT NACIO $TNACIO.;
FORMAT NACIO1 $TNACIOP.;
FORMAT NACIO2 $TNACIOP.;
FORMAT PAIS_NACI $TNACIP.;
FORMAT T_CENTRO $TCENTRO.;
FORMAT CCAA $TCCAA.;
FORMAT GRUPO_ACT $TCODGRU.;
FORMAT DISCA $T1SINO.;
FORMAT PROXY $TPROXY.;
FORMAT LUG_RES_PAIS $T1PAIS.;
FORMAT CA_RES $TCCAA.;
FORMAT PAIS_NAC_PADRE $TNACIP.;
FORMAT ESTUDIOS_PADRE $TNFORMA.;
FORMAT PAIS_NAC_MADRE $TNACIP.;
FORMAT ESTUDIOS_MADRE $TNFORMA.;
FORMAT EST_B0A $T2SINO.;
FORMAT EST_B0B $T2PAIS.;
FORMAT EST_B0C $TMESF.;
FORMAT EST_B1 $TACCES.;
FORMAT EST_B2 $TESTU.;
FORMAT EST_B3A $TMOD.;
FORMAT EST_B3B_1 $TFAMIGM.;
FORMAT EST_B3B_2 $TFAMIGS.;
FORMAT EST_B3C $TAMBITO.;
FORMAT EST_B5 $TRAZON.;
FORMAT EST_B6 $TCENTRO.;
FORMAT EST_B7 $T2SINO.;
FORMAT ESTA_B8 $T1MOTIV.;
FORMAT ESTA_B9 $T2SINO.;
FORMAT ESTA_B10 $T2MOTIV.;
FORMAT ESTA_B11 $T1CURSO.;
FORMAT EST_B12 $TESTU.;
FORMAT EST_B14A $TMOD.;
FORMAT EST_B14B_1 $TFAMIGM.;
FORMAT EST_B14B_2 $TFAMIGS.;
FORMAT EST_B14C $TAMBITO.;
FORMAT EST_B16 $T3MOTIV.;
FORMAT EST_B18 $TCENTRO.;
FORMAT EST_B19 $T2SINO.;
FORMAT ESTA_B20 $T1MOTIV.;
FORMAT ESTA_B21 $T2SINO.;
FORMAT ESTA_B22 $T2MOTIV.;
FORMAT ESTA_B23 $T2CURSO.;
FORMAT EST_B24 $TESTU.;
FORMAT EST_B26A $TMOD.;
FORMAT EST_B26B_1 $TFAMIGM.;
FORMAT EST_B26B_2 $TFAMIGS.;
FORMAT EST_B26C $TAMBITO.;
FORMAT EST_B28 $T3MOTIV.;
FORMAT EST_B30 $TCENTRO.;
FORMAT EST_B31 $T2SINO.;
FORMAT ESTA_B32 $T1MOTIV.;
FORMAT ESTA_B33 $T2SINO.;
FORMAT ESTA_B34 $T2MOTIV.;
FORMAT ESTA_B35 $T3CURSO.;
FORMAT EST_B36 $TESTU.;
FORMAT EST_B38A $TMOD.;
FORMAT EST_B38B_1 $TFAMIGM.;
FORMAT EST_B38B_2 $TFAMIGS.;
FORMAT EST_B38C $TAMBITO.;
FORMAT EST_B40 $T3MOTIV.;
FORMAT EST_B42 $TCENTRO.;
FORMAT EST_B43 $T2SINO.;
FORMAT ESTA_B44 $T1MOTIV.;
FORMAT ESTA_B45 $T2SINO.;
FORMAT ESTA_B46 $T2MOTIV.;
FORMAT ESTA_B46B $T4CURSO.;
FORMAT EST_B47 $TESTU.;
FORMAT EST_B49A $TMOD.;
FORMAT EST_B49B_1 $TFAMIGM.;
FORMAT EST_B49B_2 $TFAMIGS.;
FORMAT EST_B49C $TAMBITO.;
FORMAT EST_B51 $T3MOTIV.;
FORMAT EST_B53 $TCENTRO.;
FORMAT EST_B53T $T2SINO.;
FORMAT ESTA_B54 $T1MOTIV.;
FORMAT ESTA_B55 $T2SINO.;
FORMAT ESTA_B56 $T2MOTIV.;
FORMAT EST_B57 $TESTU.;
FORMAT EST_B59A $TMOD.;
FORMAT EST_B59B_1 $TFAMIGM.;
FORMAT EST_B59B_2 $TFAMIGS.;
FORMAT EST_B59C $TAMBITO.;
FORMAT EST_B61 $T3MOTIV.;
FORMAT EST_B63 $TCENTRO.;
FORMAT ESTA_B64 $T1MOTIV.;
FORMAT C1_4 $T1SINO.;
FORMAT C1_6 $T1SINO.;
FORMAT C1_7 $T1SINO.;
FORMAT C2_4 $T2SINO.;
FORMAT C2_6 $T2SINO.;
FORMAT IDI_MT1 $Tidioma.;
FORMAT IDI_MT2 $Tidioma.;
FORMAT IDIOMAS $TNUMIDI.;
FORMAT IDIOMA1 $Tidioma.;
FORMAT NIV_ID1 $TNivIdi.;
FORMAT ACREIDI1 $T2SINO.;
FORMAT IDIOMA2 $Tidioma.;
FORMAT NIV_ID2 $TNivIdi.;
FORMAT ACREIDI2 $T2SINO.;
FORMAT IDIOMA3 $Tidioma.;
FORMAT NIV_ID3 $TNivIdi.;
FORMAT ACREIDI3 $T2SINO.;
FORMAT IDIOMA4 $Tidioma.;
FORMAT NIV_ID4 $TNivIdi.;
FORMAT ACREIDI4 $T2SINO.;
FORMAT TITIDI $T2SINO.;
FORMAT TIC $TTIC.;
FORMAT C8_1 $T1SINO.;
FORMAT C8_2 $T1SINO.;
FORMAT C8_3 $T1SINO.;
FORMAT C8_4 $T1SINO.;
FORMAT C8_5 $T1SINO.;
FORMAT C8_6 $T1SINO.;
FORMAT C8_7 $T1SINO.;
FORMAT C9_1 $T2SINO.;
FORMAT C9_2 $T2SINO.;
FORMAT C9_3 $T2SINO.;
FORMAT C9_4 $T2SINO.;
FORMAT C9_5 $T2SINO.;
FORMAT C9_6 $T2SINO.;
FORMAT C9_7 $T2SINO.;
FORMAT MOV_IN $T2SINO.;
FORMAT MOV_IN_CA $TCCAA.;
FORMAT MOVRAZ1 $T2SINO.;
FORMAT MOVRAZ2 $T2SINO.;
FORMAT MOVRAZ3 $T2SINO.;
FORMAT MOVRAZ4 $T2SINO.;
FORMAT MOVRAZ5 $T2SINO.;
FORMAT MVFUERA $T2SINO.;
FORMAT MOVPAI1 $TPAIMOV.;
FORMAT MOVPAI2 $TPAIMOV.;
FORMAT MOVPAI3 $TPAIMOV.;
FORMAT MOVRA21 $T2SINO.;
FORMAT MOVRA22 $T2SINO.;
FORMAT MOVRA23 $T2SINO.;
FORMAT MOVRA24 $T2SINO.;
FORMAT MOVRA25 $T2SINO.;
FORMAT MOVRA26 $T2SINO.;
FORMAT MOV_D7 $TVIVIRF.;
FORMAT MOV_D8_1 $T2SINO.;
FORMAT MOV_D8_2 $T2SINO.;
FORMAT MOV_D8_3 $T2SINO.;
FORMAT MOV_D8_4 $T2SINO.;
FORMAT MOV_D8_5 $T2SINO.;
FORMAT MOV_D8_6 $T2SINO.;
FORMAT MOV_D9 $TPAIMOV.;
FORMAT RETORNO $T2SINO.;
FORMAT TRBPRN1 $T1TRBPN.;
FORMAT TRBPRN2 $T2TRBPN.;
FORMAT TRINAC_E4 $T2SINO.;
FORMAT TRINAC_E5 $T1MOBUT.;
FORMAT TRINAC_E6 $T1TIEMP.;
FORMAT TRPARA_E5 $T1MOBUT.;
FORMAT TRPARA_E6 $T1TIEMP.;
FORMAT TRPARA_E7_1 $T2SINO.;
FORMAT TRPARA_E7_2 $T2SINO.;
FORMAT TRPARA_E7_3 $T2SINO.;
FORMAT TRPARA_E7_4 $T2SINO.;
FORMAT TRPARA_E7_5 $T2SINO.;
FORMAT TRPARA_E7_6 $T2SINO.;
FORMAT TRPARA_E7_7 $T2SINO.;
FORMAT TRPARA_E7_8 $T2SINO.;
FORMAT TRPARA_E7_9 $T2SINO.;
FORMAT TRPARA_E8_1 $TIMPORT.;
FORMAT TRPARA_E8_2 $TIMPORT.;
FORMAT TRPARA_E8_3 $TIMPORT.;
FORMAT TRPARA_E8_4 $TIMPORT.;
FORMAT TRPARA_E8_5 $TIMPORT.;
FORMAT TRPARA_E8_6 $TIMPORT.;
FORMAT TRPARA_E8_7 $TIMPORT.;
FORMAT TRPARA_E8_8 $TIMPORT.;
FORMAT TRAC_E9 $T2SINO.;
FORMAT LUG_TRAB_PAIS $T1PAIS.;
FORMAT CATRAB $TCCAA.;
FORMAT SIT_PRO $TStProf.;
FORMAT JORNADA $TJornad.;
FORMAT TRABOC $TOcupac.;
FORMAT TR_CNAE $TCNAE.;
FORMAT TR_TAM $TTamano.;
FORMAT TR_ANIO $TAnio.;
FORMAT TR_SUELDO $TSUELDO.;
FORMAT TR_E19 $TNivEst.;
FORMAT TR_E20 $TFORM.;
FORMAT TR_E21_1 $TFacTrb.;
FORMAT TR_E21_2 $TFacTrb.;
FORMAT TR_E21_3 $TFacTrb.;
FORMAT TR_E21_4 $TFacTrb.;
FORMAT TR_E21_5 $TFacTrb.;
FORMAT TR_E21_6 $TFacTrb.;
FORMAT TR_E22 $T3SiNo.;
FORMAT HL_F1 $T1SINO.;
FORMAT HL_F2 $T2SINO.;
FORMAT HL_F3 $T2SINO.;
FORMAT HL_F4 $T2SINO.;
FORMAT HL_F5 $T1SATIS.;
FORMAT HL_F6 $T1SINO.;
FORMAT HL_F8 $T2SINO.;
FORMAT HL_JOR $TJornad.;
FORMAT HL_F10 $T2SINO.;
FORMAT HL_F11 $T2SINO.;
FORMAT HA_TRAB $T1SINO.;
FORMAT HATR_F14 $T2TIEMP.;
FORMAT HATR_F15 $T2MOBUT.;
FORMAT HATR_BSQ1 $T2SINO.;
FORMAT HATR_BSQ2 $T2SINO.;
FORMAT HATR_BSQ3 $T2SINO.;
FORMAT HATR_BSQ4 $T2SINO.;
FORMAT HATR_BSQ5 $T2SINO.;
FORMAT HATR_BSQ6 $T2SINO.;
FORMAT HATR_BSQ7 $T2SINO.;
FORMAT HATR_BSQ8 $T2SINO.;
FORMAT HATR_BSQ9 $T2SINO.;
FORMAT HATR_BSQ10 $T2SINO.;
FORMAT P_CONTI $T2SINO.;
FORMAT PR_F20 $T2SINO.;
FORMAT PR_PAIS $T1PAIS.;
FORMAT PR_CA $TCCAA.;
FORMAT PR_OCU $TOcupac.;
FORMAT PR_SIT_PR $TStProf.;
FORMAT PR_JOR $TJornad.;
FORMAT PR_NIVEL $TNivEst.;
FORMAT PR_FORM $TFORM.;
FORMAT PR_SUELDO $TSUELDO.;
FORMAT HATR_TIEMP $T3TIEMP.;
FORMAT HATR_NUM $TNmEmpl.;
FORMAT HATR_F30 $T2SINO.;
FORMAT HATR_F31 $T2SATIS.;
FORMAT HATR_F32 $T2SINO.;
FORMAT NOTRAB_BUS $T2SINO.;
FORMAT NOTRAB_BUSM $T1MOBUT.;
FORMAT NOTRAB_BUST $T1TIEMP.;
FORMAT NOTRAB_BSQ1 $T2SINO.;
FORMAT NOTRAB_BSQ2 $T2SINO.;
FORMAT NOTRAB_BSQ3 $T2SINO.;
FORMAT NOTRAB_BSQ4 $T2SINO.;
FORMAT NOTRAB_BSQ5 $T2SINO.;
FORMAT NOTRAB_BSQ6 $T2SINO.;
FORMAT NOTRAB_BSQ7 $T2SINO.;
FORMAT NOTRAB_BSQ8 $T2SINO.;
FORMAT NOTRAB_BSQ9 $T2SINO.;
FORMAT NOTRAB_DIF1 $TIMPORT.;
FORMAT NOTRAB_DIF2 $TIMPORT.;
FORMAT NOTRAB_DIF3 $TIMPORT.;
FORMAT NOTRAB_DIF4 $TIMPORT.;
FORMAT NOTRAB_DIF5 $TIMPORT.;
FORMAT NOTRAB_DIF6 $TIMPORT.;
FORMAT NOTRAB_DIF7 $TIMPORT.;
FORMAT NOTRAB_DIF8 $TIMPORT.;
FORMAT RECHA_TR $T2SINO.;
FORMAT RECHA_M1 $T2SINO.;
FORMAT RECHA_M2 $T2SINO.;
FORMAT RECHA_M3 $T2SINO.;
FORMAT RECHA_M4 $T2SINO.;
FORMAT RECHA_M5 $T2SINO.;
FORMAT RECHA_M6 $T2SINO.;
FORMAT RECHA_M7 $T2SINO.;
FORMAT RECHA_M8 $T2SINO.;
FORMAT RECHA_M9 $T2SINO.;
FORMAT HO_G1 $TESTCIV.;
FORMAT HO_PAREJ $T2SINO.;
FORMAT HO_NPER $TNPER.;
FORMAT HO_NPER_TR $TNPER.;
FORMAT HO_TIPO $TTIPO.;
FORMAT ALSSM15 $T1SINO.;
FORMAT COTIZ15 $TCOTIZ.;

FORMAT BCOTC15 $TQuintl.;
FORMAT ALSSM16 $T1SINO.;
FORMAT COTIZ16 $TCOTIZ.;

FORMAT BCOTC16 $TQuintl.;
FORMAT ALSSM17 $T1SINO.;
FORMAT COTIZ17 $TCOTIZ.;

FORMAT BCOTC17 $TQuintl.;
FORMAT ALSSM18 $T1SINO.;
FORMAT COTIZ18 $TCOTIZ.;

FORMAT BCOTC18 $TQuintl.;
FORMAT ALSSM19 $T1SINO.;
FORMAT COTIZ19 $TCOTIZ.;

FORMAT BCOTC19 $TQuintl.;
FORMAT N_CURS $TNuCurs.;
FORMAT DENCUR1 $TDsCurs.;
FORMAT DURCUR1 $TDrCurs.;
FORMAT RESCUR1 $TReCurs.;
FORMAT ANHCUR1 $TAnCurs.;
FORMAT DENCUR2 $TDsCurs.;
FORMAT DURCUR2 $TDrCurs.;
FORMAT RESCUR2 $TReCurs.;
FORMAT ANHCUR2 $TAnCurs.;
FORMAT DENCUR3 $TDsCurs.;
FORMAT DURCUR3 $TDrCurs.;
FORMAT RESCUR3 $TReCurs.;
FORMAT ANHCUR3 $TAnCurs.;
FORMAT DENCUR4 $TDsCurs.;
FORMAT DURCUR4 $TDrCurs.;
FORMAT RESCUR4 $TReCurs.;
FORMAT ANHCUR4 $TAnCurs.;
FORMAT DENCUR5 $TDsCurs.;
FORMAT DURCUR5 $TDrCurs.;
FORMAT RESCUR5 $TReCurs.;
FORMAT ANHCUR5 $TAnCurs.;
FORMAT DENCUR6 $TDsCurs.;
FORMAT DURCUR6 $TDrCurs.;
FORMAT RESCUR6 $TReCurs.;
FORMAT ANHCUR6 $TAnCurs.;


RUN;
/* FIN PROGRAMA: Microdatos en SAS: ETEFIL_GM_2019.sas*/
